import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@kubernetes-models/base";
export interface IInternalPackage {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": "internal.packaging.carvel.dev/v1alpha1";
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": "InternalPackage";
    "metadata"?: IObjectMeta;
    "spec": {
        "capacityRequirementsDescription"?: string;
        "licenses"?: Array<string>;
        "refName"?: string;
        "releaseNotes"?: string;
        "releasedAt"?: string;
        "template"?: {
            "spec": {
                /**
                 * Canceled when set to true will stop all active changes
                 */
                "canceled"?: boolean;
                "cluster"?: {
                    "kubeconfigSecretRef"?: {
                        "key"?: string;
                        "name"?: string;
                    };
                    "namespace"?: string;
                };
                "deploy"?: Array<{
                    "kapp"?: {
                        "delete"?: {
                            "rawOptions"?: Array<string>;
                        };
                        "inspect"?: {
                            "rawOptions"?: Array<string>;
                        };
                        "intoNs"?: string;
                        "mapNs"?: Array<string>;
                        "rawOptions"?: Array<string>;
                    };
                }>;
                "fetch"?: Array<{
                    /**
                     * TODO implement git
                     */
                    "git"?: {
                        "lfsSkipSmudge"?: boolean;
                        "ref"?: string;
                        "refSelection"?: {
                            "semver"?: {
                                "constraints"?: string;
                                "prereleases"?: {
                                    "identifiers"?: Array<string>;
                                };
                            };
                        };
                        /**
                         * Secret may include one or more keys: ssh-privatekey, ssh-knownhosts
                         */
                        "secretRef"?: {
                            /**
                             * Object is expected to be within same namespace
                             */
                            "name"?: string;
                        };
                        "subPath"?: string;
                        "url"?: string;
                    };
                    "helmChart"?: {
                        /**
                         * Example: stable/redis
                         */
                        "name"?: string;
                        "repository"?: {
                            "secretRef"?: {
                                /**
                                 * Object is expected to be within same namespace
                                 */
                                "name"?: string;
                            };
                            "url"?: string;
                        };
                        "version"?: string;
                    };
                    "http"?: {
                        /**
                         * Secret may include one or more keys: username, password
                         */
                        "secretRef"?: {
                            /**
                             * Object is expected to be within same namespace
                             */
                            "name"?: string;
                        };
                        "sha256"?: string;
                        "subPath"?: string;
                        /**
                         * URL can point to one of following formats: text, tgz, zip
                         */
                        "url"?: string;
                    };
                    "image"?: {
                        /**
                         * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                         */
                        "secretRef"?: {
                            /**
                             * Object is expected to be within same namespace
                             */
                            "name"?: string;
                        };
                        "subPath"?: string;
                        "tagSelection"?: {
                            "semver"?: {
                                "constraints"?: string;
                                "prereleases"?: {
                                    "identifiers"?: Array<string>;
                                };
                            };
                        };
                        /**
                         * Example: username/app1-config:v0.1.0
                         */
                        "url"?: string;
                    };
                    "imgpkgBundle"?: {
                        "image"?: string;
                        /**
                         * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                         */
                        "secretRef"?: {
                            /**
                             * Object is expected to be within same namespace
                             */
                            "name"?: string;
                        };
                        "tagSelection"?: {
                            "semver"?: {
                                "constraints"?: string;
                                "prereleases"?: {
                                    "identifiers"?: Array<string>;
                                };
                            };
                        };
                    };
                    "inline"?: {
                        "paths"?: {
                            [key: string]: string;
                        };
                        "pathsFrom"?: Array<{
                            "configMapRef"?: {
                                "directoryPath"?: string;
                                "name"?: string;
                            };
                            "secretRef"?: {
                                "directoryPath"?: string;
                                "name"?: string;
                            };
                        }>;
                    };
                }>;
                /**
                 * When NoopDeletion set to true, App deletion should delete App CR but preserve App's associated resources
                 */
                "noopDelete"?: boolean;
                /**
                 * Paused when set to true will ignore all pending changes, once it set back to false, pending changes will be applied
                 */
                "paused"?: boolean;
                "serviceAccountName"?: string;
                /**
                 * Controls frequency of app reconciliation
                 */
                "syncPeriod"?: string;
                "template"?: Array<{
                    "helmTemplate"?: {
                        "name"?: string;
                        "namespace"?: string;
                        "path"?: string;
                        "valuesFrom"?: Array<{
                            "configMapRef"?: {
                                "name"?: string;
                            };
                            "path"?: string;
                            "secretRef"?: {
                                "name"?: string;
                            };
                        }>;
                    };
                    /**
                     * TODO implement jsonnet
                     */
                    "jsonnet"?: {};
                    "kbld"?: {
                        "paths"?: Array<string>;
                    };
                    /**
                     * TODO implement kustomize
                     */
                    "kustomize"?: {};
                    "sops"?: {
                        "age"?: {
                            "privateKeysSecretRef"?: {
                                "name"?: string;
                            };
                        };
                        "paths"?: Array<string>;
                        "pgp"?: {
                            "privateKeysSecretRef"?: {
                                "name"?: string;
                            };
                        };
                    };
                    "ytt"?: {
                        "fileMarks"?: Array<string>;
                        "ignoreUnknownComments"?: boolean;
                        "inline"?: {
                            "paths"?: {
                                [key: string]: string;
                            };
                            "pathsFrom"?: Array<{
                                "configMapRef"?: {
                                    "directoryPath"?: string;
                                    "name"?: string;
                                };
                                "secretRef"?: {
                                    "directoryPath"?: string;
                                    "name"?: string;
                                };
                            }>;
                        };
                        "paths"?: Array<string>;
                        "strict"?: boolean;
                        "valuesFrom"?: Array<{
                            "configMapRef"?: {
                                "name"?: string;
                            };
                            "path"?: string;
                            "secretRef"?: {
                                "name"?: string;
                            };
                        }>;
                    };
                }>;
            };
        };
        /**
         * valuesSchema can be used to show template values that can be configured by users when a Package is installed in an OpenAPI schema format.
         */
        "valuesSchema"?: {
            "openAPIv3"?: {};
        };
        "version"?: string;
    };
}
export declare class InternalPackage extends Model<IInternalPackage> implements IInternalPackage {
    "apiVersion": IInternalPackage["apiVersion"];
    "kind": IInternalPackage["kind"];
    "metadata"?: IInternalPackage["metadata"];
    "spec": IInternalPackage["spec"];
    static apiVersion: IInternalPackage["apiVersion"];
    static kind: IInternalPackage["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IInternalPackage>;
    constructor(data?: ModelData<IInternalPackage>);
}
