import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@kubernetes-models/base";
export interface IApp {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": "kappctrl.k14s.io/v1alpha1";
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": "App";
    "metadata"?: IObjectMeta;
    "spec": {
        /**
         * Canceled when set to true will stop all active changes
         */
        "canceled"?: boolean;
        "cluster"?: {
            "kubeconfigSecretRef"?: {
                "key"?: string;
                "name"?: string;
            };
            "namespace"?: string;
        };
        "deploy"?: Array<{
            "kapp"?: {
                "delete"?: {
                    "rawOptions"?: Array<string>;
                };
                "inspect"?: {
                    "rawOptions"?: Array<string>;
                };
                "intoNs"?: string;
                "mapNs"?: Array<string>;
                "rawOptions"?: Array<string>;
            };
        }>;
        "fetch"?: Array<{
            /**
             * TODO implement git
             */
            "git"?: {
                "lfsSkipSmudge"?: boolean;
                "ref"?: string;
                "refSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
                /**
                 * Secret may include one or more keys: ssh-privatekey, ssh-knownhosts
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "subPath"?: string;
                "url"?: string;
            };
            "helmChart"?: {
                /**
                 * Example: stable/redis
                 */
                "name"?: string;
                "repository"?: {
                    "secretRef"?: {
                        /**
                         * Object is expected to be within same namespace
                         */
                        "name"?: string;
                    };
                    "url"?: string;
                };
                "version"?: string;
            };
            "http"?: {
                /**
                 * Secret may include one or more keys: username, password
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "sha256"?: string;
                "subPath"?: string;
                /**
                 * URL can point to one of following formats: text, tgz, zip
                 */
                "url"?: string;
            };
            "image"?: {
                /**
                 * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "subPath"?: string;
                "tagSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
                /**
                 * Example: username/app1-config:v0.1.0
                 */
                "url"?: string;
            };
            "imgpkgBundle"?: {
                "image"?: string;
                /**
                 * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "tagSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
            };
            "inline"?: {
                "paths"?: {
                    [key: string]: string;
                };
                "pathsFrom"?: Array<{
                    "configMapRef"?: {
                        "directoryPath"?: string;
                        "name"?: string;
                    };
                    "secretRef"?: {
                        "directoryPath"?: string;
                        "name"?: string;
                    };
                }>;
            };
        }>;
        /**
         * When NoopDeletion set to true, App deletion should delete App CR but preserve App's associated resources
         */
        "noopDelete"?: boolean;
        /**
         * Paused when set to true will ignore all pending changes, once it set back to false, pending changes will be applied
         */
        "paused"?: boolean;
        "serviceAccountName"?: string;
        /**
         * Controls frequency of app reconciliation
         */
        "syncPeriod"?: string;
        "template"?: Array<{
            "helmTemplate"?: {
                "name"?: string;
                "namespace"?: string;
                "path"?: string;
                "valuesFrom"?: Array<{
                    "configMapRef"?: {
                        "name"?: string;
                    };
                    "path"?: string;
                    "secretRef"?: {
                        "name"?: string;
                    };
                }>;
            };
            /**
             * TODO implement jsonnet
             */
            "jsonnet"?: {};
            "kbld"?: {
                "paths"?: Array<string>;
            };
            /**
             * TODO implement kustomize
             */
            "kustomize"?: {};
            "sops"?: {
                "age"?: {
                    "privateKeysSecretRef"?: {
                        "name"?: string;
                    };
                };
                "paths"?: Array<string>;
                "pgp"?: {
                    "privateKeysSecretRef"?: {
                        "name"?: string;
                    };
                };
            };
            "ytt"?: {
                "fileMarks"?: Array<string>;
                "ignoreUnknownComments"?: boolean;
                "inline"?: {
                    "paths"?: {
                        [key: string]: string;
                    };
                    "pathsFrom"?: Array<{
                        "configMapRef"?: {
                            "directoryPath"?: string;
                            "name"?: string;
                        };
                        "secretRef"?: {
                            "directoryPath"?: string;
                            "name"?: string;
                        };
                    }>;
                };
                "paths"?: Array<string>;
                "strict"?: boolean;
                "valuesFrom"?: Array<{
                    "configMapRef"?: {
                        "name"?: string;
                    };
                    "path"?: string;
                    "secretRef"?: {
                        "name"?: string;
                    };
                }>;
            };
        }>;
    };
    "status"?: {
        "conditions"?: Array<{
            /**
             * Human-readable message indicating details about last transition.
             */
            "message"?: string;
            /**
             * Unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "ResizeStarted" that means the underlying persistent volume is being resized.
             */
            "reason"?: string;
            "status": string;
            "type": string;
        }>;
        "consecutiveReconcileFailures"?: number;
        "consecutiveReconcileSuccesses"?: number;
        "deploy"?: {
            "error"?: string;
            "exitCode"?: number;
            "finished"?: boolean;
            "startedAt"?: string;
            "stderr"?: string;
            "stdout"?: string;
            "updatedAt"?: string;
        };
        "fetch"?: {
            "error"?: string;
            "exitCode"?: number;
            "startedAt"?: string;
            "stderr"?: string;
            "stdout"?: string;
            "updatedAt"?: string;
        };
        "friendlyDescription"?: string;
        "inspect"?: {
            "error"?: string;
            "exitCode"?: number;
            "stderr"?: string;
            "stdout"?: string;
            "updatedAt"?: string;
        };
        "managedAppName"?: string;
        "observedGeneration"?: number;
        "template"?: {
            "error"?: string;
            "exitCode"?: number;
            "stderr"?: string;
            "updatedAt"?: string;
        };
        "usefulErrorMessage"?: string;
    };
}
export declare class App extends Model<IApp> implements IApp {
    "apiVersion": IApp["apiVersion"];
    "kind": IApp["kind"];
    "metadata"?: IApp["metadata"];
    "spec": IApp["spec"];
    "status"?: IApp["status"];
    static apiVersion: IApp["apiVersion"];
    static kind: IApp["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IApp>;
    constructor(data?: ModelData<IApp>);
}
