import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@kubernetes-models/base";
export interface IPackageRepository {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": "packaging.carvel.dev/v1alpha1";
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": "PackageRepository";
    "metadata"?: IObjectMeta;
    "spec": {
        "fetch": {
            /**
             * TODO implement git
             */
            "git"?: {
                "lfsSkipSmudge"?: boolean;
                "ref"?: string;
                "refSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
                /**
                 * Secret may include one or more keys: ssh-privatekey, ssh-knownhosts
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "subPath"?: string;
                "url"?: string;
            };
            "http"?: {
                /**
                 * Secret may include one or more keys: username, password
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "sha256"?: string;
                "subPath"?: string;
                /**
                 * URL can point to one of following formats: text, tgz, zip
                 */
                "url"?: string;
            };
            "image"?: {
                /**
                 * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "subPath"?: string;
                "tagSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
                /**
                 * Example: username/app1-config:v0.1.0
                 */
                "url"?: string;
            };
            "imgpkgBundle"?: {
                "image"?: string;
                /**
                 * Secret may include one or more keys: username, password, token. By default anonymous access is used for authentication. TODO support docker config formated secret
                 */
                "secretRef"?: {
                    /**
                     * Object is expected to be within same namespace
                     */
                    "name"?: string;
                };
                "tagSelection"?: {
                    "semver"?: {
                        "constraints"?: string;
                        "prereleases"?: {
                            "identifiers"?: Array<string>;
                        };
                    };
                };
            };
        };
        /**
         * Paused when set to true will ignore all pending changes, once it set back to false, pending changes will be applied
         */
        "paused"?: boolean;
        /**
         * Controls frequency of PackageRepository reconciliation
         */
        "syncPeriod"?: string;
    };
    "status"?: {
        "conditions"?: Array<{
            /**
             * Human-readable message indicating details about last transition.
             */
            "message"?: string;
            /**
             * Unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "ResizeStarted" that means the underlying persistent volume is being resized.
             */
            "reason"?: string;
            "status": string;
            "type": string;
        }>;
        "consecutiveReconcileFailures"?: number;
        "consecutiveReconcileSuccesses"?: number;
        "deploy"?: {
            "error"?: string;
            "exitCode"?: number;
            "finished"?: boolean;
            "startedAt"?: string;
            "stderr"?: string;
            "stdout"?: string;
            "updatedAt"?: string;
        };
        "fetch"?: {
            "error"?: string;
            "exitCode"?: number;
            "startedAt"?: string;
            "stderr"?: string;
            "stdout"?: string;
            "updatedAt"?: string;
        };
        "friendlyDescription"?: string;
        "observedGeneration"?: number;
        "template"?: {
            "error"?: string;
            "exitCode"?: number;
            "stderr"?: string;
            "updatedAt"?: string;
        };
        "usefulErrorMessage"?: string;
    };
}
export declare class PackageRepository extends Model<IPackageRepository> implements IPackageRepository {
    "apiVersion": IPackageRepository["apiVersion"];
    "kind": IPackageRepository["kind"];
    "metadata"?: IPackageRepository["metadata"];
    "spec": IPackageRepository["spec"];
    "status"?: IPackageRepository["status"];
    static apiVersion: IPackageRepository["apiVersion"];
    static kind: IPackageRepository["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IPackageRepository>;
    constructor(data?: ModelData<IPackageRepository>);
}
